@@ -37,11 +37,11 @@
 #ifndef KFTPCORE_CHECKSUMVERIFIER_H
 #define KFTPCORE_CHECKSUMVERIFIER_H
 
-#include <ntqstring.h>
-#include <ntqthread.h>
-#include <ntqobject.h>
-#include <ntqvaluelist.h>
-#include <ntqpair.h>
+#include <tqstring.h>
+#include <tqthread.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
+#include <tqpair.h>
 
 namespace KFTPCore {
 
