@@ -134,7 +134,7 @@ private:
     TQCache<Site> m_siteCache;
     TQDomDocument m_document;
     
-    TQCString m_decryptKey;
+    TQString m_decryptKey;
     TQString m_filename;
     
     TQDomNode findSiteElementByUrl(const KURL &url, TQDomNode parent = TQDomNode());
