@@ -41,7 +41,7 @@
 #include "kftpqueueprocessor.h"
 #include "kftpsession.h"
 
-#include "misc/config.h"
+#include "misc/kftpconfig.h"
 #include "misc/filter.h"
 
 #include <tdemessagebox.h>
@@ -57,10 +57,10 @@
 #include <krun.h>
 #include <kmdcodec.h>
 
-#include <ntqapplication.h>
-#include <ntqregexp.h>
-#include <ntqobjectlist.h>
-#include <ntqfile.h>
+#include <tqapplication.h>
+#include <tqregexp.h>
+#include <tqobjectlist.h>
+#include <tqfile.h>
 
 using namespace KFTPEngine;
 using namespace KFTPCore::Filter;
