@@ -384,7 +384,7 @@ void Session::slotClientEngineEvent(KFTPEngine::Event *event)
     }
     case Event::EventPubkeyPassword: {
       // A public-key authentication password was requested
-      TQCString pass;
+      TQString pass;
       int ret = KPasswordDialog::getPassword(pass, i18n("Please provide your private key decryption password."));
       
       if (ret == KPasswordDialog::Accepted) {
