@@ -36,11 +36,11 @@
 #ifndef KFTPSESSION_H
 #define KFTPSESSION_H
 
-#include <ntqobject.h>
-#include <ntqguardedptr.h>
-#include <ntqdom.h>
+#include <tqobject.h>
+#include <tqguardedptr.h>
+#include <tqdom.h>
 
-#include <ntqlistview.h>
+#include <tqlistview.h>
 
 #include "kftpqueue.h"
 #include "logview.h"
